Struct WpCommitTimerV1
pub struct WpCommitTimerV1 { /* private fields */ }wayland and Linux only.Expand description
Surface commit timer
An object to set a time constraint for a content update on a surface.
This interface has no events.
Implementations
impl WpCommitTimerV1
impl WpCommitTimerV1
pub fn set_timestamp(&self, tv_sec_hi: u32, tv_sec_lo: u32, tv_nsec: u32)
pub fn set_timestamp(&self, tv_sec_hi: u32, tv_sec_lo: u32, tv_nsec: u32)
Specify time the following commit takes effect
Provide a timing constraint for a surface content update.
A set_timestamp request may be made before a wl_surface.commit to tell the compositor that the content is intended to be presented as closely as possible to, but not before, the specified time. The time is in the domain of the compositor’s presentation clock.
An invalid_timestamp error will be generated for invalid tv_nsec.
If a timestamp already exists on the surface, a timestamp_exists error is generated.
Requesting set_timestamp after the commit_timer object’s surface is destroyed will generate a “surface_destroyed” error.
pub fn destroy(&self)
pub fn destroy(&self)
Destroy the timer
Informs the server that the client will no longer be using this protocol object.
Existing timing constraints are not affected by the destruction.